API
===

Sobol
-----
.. autofunction:: pyscenarios.sobol
.. autofunction:: pyscenarios.max_sobol_dimensions


Copulas
-------
.. autofunction:: pyscenarios.gaussian_copula
.. autofunction:: pyscenarios.t_copula


Statistical functions
---------------------
.. autofunction:: pyscenarios.tail_dependence
